==> abcl-0.0.9.tar.gz: abcl-0.0.9/src/org/armedbear/lisp/ProgramError.java <==
/*
 * ProgramError.java
 *
 * Copyright (C) 2003-2005 Peter Graves
 * $Id: ProgramError.java,v 1.14 2005/06/22 18:21:08 piso Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.armedbear.lisp;

public class ProgramError extends LispError
{
    protected ProgramError(LispClass cls)
    {
        super(cls);
    }

    public ProgramError(LispObject initArgs) throws ConditionThrowable
    {
        super(StandardClass.PROGRAM_ERROR);
        initialize(initArgs);
    }

    public ProgramError(String message) throws ConditionThrowable
    {
        super(StandardClass.PROGRAM_ERROR);
        setFormatControl(message);
        setFormatArguments(NIL);
    }

    public LispObject typeOf()
    {
        return Symbol.PROGRAM_ERROR;
    }

    public LispObject classOf()
    {
        return StandardClass.PROGRAM_ERROR;
    }

    public LispObject typep(LispObject type) throws ConditionThrowable
    {
        if (type == Symbol.PROGRAM_ERROR)
            return T;
        if (type == StandardClass.PROGRAM_ERROR)
            return T;
        return super.typep(type);
    }
}

==> abcl-0.0.10.tar.gz: abcl-0.0.10/src/org/armedbear/lisp/ProgramError.java <==
/*
 * ProgramError.java
 *
 * Copyright (C) 2003-2005 Peter Graves
 * $Id: ProgramError.java,v 1.15 2005/11/01 01:40:41 piso Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.armedbear.lisp;

public class ProgramError extends LispError
{
    protected ProgramError(LispClass cls) throws ConditionThrowable
    {
        super(cls);
    }

    public ProgramError(LispObject initArgs) throws ConditionThrowable
    {
        super(StandardClass.PROGRAM_ERROR);
        initialize(initArgs);
    }

    public ProgramError(String message) throws ConditionThrowable
    {
        super(StandardClass.PROGRAM_ERROR);
        setFormatControl(message);
        setFormatArguments(NIL);
    }

    public LispObject typeOf()
    {
        return Symbol.PROGRAM_ERROR;
    }

    public LispObject classOf()
    {
        return StandardClass.PROGRAM_ERROR;
    }

    public LispObject typep(LispObject type) throws ConditionThrowable
    {
        if (type == Symbol.PROGRAM_ERROR)
            return T;
        if (type == StandardClass.PROGRAM_ERROR)
            return T;
        return super.typep(type);
    }
}
